@@ -50,12 +50,16 @@ stds.luajit = {
    "setmetatable", "string", "table", "tonumber", "tostring", "type", "unpack", "xpcall"}
 
 stds.ngx_lua = {
-   _G = true, package = true, "_VERSION", "arg", "assert", "bit", "collectgarbage", "coroutine",
+   _G = true, ngx = true, package = true, "_VERSION", "arg", "assert", "bit", "collectgarbage", "coroutine",
    "debug", "dofile", "error", "gcinfo", "getfenv", "getmetatable", "io", "ipairs", "jit",
-   "load", "loadfile", "loadstring", "math", "module", "newproxy", "ndk", "ngx", "next", "os",
+   "load", "loadfile", "loadstring", "math", "module", "newproxy", "ndk", "next", "os",
    "pairs", "pcall", "print", "rawequal", "rawget", "rawset", "require", "select", "setfenv",
    "setmetatable", "string", "table", "tonumber", "tostring", "type", "unpack", "xpcall"}
 
+stds.rockspec = {
+   rockspec_format = true, package = true, version = true, description = true, supported_platforms = true,
+   dependencies = true, external_dependencies = true, source = true, build = true}
+
 local min = {_G = true, package = true}
 local std_sets = {}
 
